@@ -19,7 +19,17 @@ $Data{'currency'}{'iso'}{'orig'}{'name'} = {
    "US Dollar (Next day) " => "US Dollar (Next day)",
    "US Dollar (Same day) " => "US Dollar (Same day)",
    "Bond Markets Unit European Monetary Unit (E.M.U.-6) "
-                           => "Bond Markets Unit European Monetary Unit (E.M.U.-6)",
+                           => "Bond Markets Unit European Monetary Unit (E.M.U.-6)",   "LAND ISLANDS"      => "Aland Islands",
+   "CTE D'IVOIRE"      => "Cote d'Ivoire",
+   "CURAAO"            => "Curacao",
+   "INTERNATIONAL MONETARY FUND (IMF)"
+                           => "International Monetary Fund (IMF)",
+   "KOREA, DEMOCRATIC PEOPLE’S REPUBLIC OF"
+                           => "Korea, Democratic People's Republic of",
+   "LAO PEOPLE’S DEMOCRATIC REPUBLIC"
+                           => "Lao People's Democratic Republic",
+   "RUNION"            => "Reunion",
+   "SAINT BARTHLEMY"   => "Saint Barthelemy",
 };
 
 $Data{'currency'}{'iso'}{'ignore'} = {
